@@ -17,7 +17,6 @@ import warnings
 
 from collections.abc import Sequence
 from types import ModuleType
-from typing import Optional, Union
 
 import numpy as np
 import pytensor.tensor as pt
@@ -28,10 +27,10 @@ from pymc.gp.cov import Covariance, Periodic
 from pymc.gp.gp import Base
 from pymc.gp.mean import Mean, Zero
 
-TensorLike = Union[np.ndarray, pt.TensorVariable]
+TensorLike = np.ndarray | pt.TensorVariable
 
 
-def set_boundary(Xs: TensorLike, c: Union[numbers.Real, TensorLike]) -> TensorLike:
+def set_boundary(Xs: TensorLike, c: numbers.Real | TensorLike) -> TensorLike:
     """Set the boundary using the mean-subtracted `Xs` and `c`.  `c` is usually a scalar
     multiplyer greater than 1.0, but it may be one value per dimension or column of `Xs`.
     """
@@ -176,10 +175,10 @@ class HSGP(Base):
     def __init__(
         self,
         m: Sequence[int],
-        L: Optional[Sequence[float]] = None,
-        c: Optional[numbers.Real] = None,
+        L: Sequence[float] | None = None,
+        c: numbers.Real | None = None,
         drop_first: bool = False,
-        parameterization: Optional[str] = "noncentered",
+        parameterization: str | None = "noncentered",
         *,
         mean_func: Mean = Zero(),
         cov_func: Covariance,
@@ -220,7 +219,7 @@ class HSGP(Base):
         self._drop_first = drop_first
         self._m = m
         self._m_star = int(np.prod(self._m))
-        self._L: Optional[pt.TensorVariable] = None
+        self._L: pt.TensorVariable | None = None
         if L is not None:
             self._L = pt.as_tensor(L)
         self._c = c
@@ -252,7 +251,7 @@ class HSGP(Base):
         eigenfunctions `phi`, and the square root of the power spectral density.
 
         Correct results when using `prior_linearized` in tandem with `pm.set_data` and
-        `pm.MutableData` require two conditions.  First, one must specify `L` instead of `c` when
+        `pm.Data` require two conditions.  First, one must specify `L` instead of `c` when
         the GP is constructed.  If not, a RuntimeError is raised.  Second, the `Xs` needs to be
         zero-centered, so its mean must be subtracted.  An example is given below.
 
@@ -290,7 +289,7 @@ class HSGP(Base):
                 # First calculate the mean, then make X a shared variable, then subtract the mean.
                 #  When X is mutated later, the correct mean will be subtracted.
                 X_mean = np.mean(X, axis=0)
-                X = pm.MutableData("X", X)
+                X = pm.Data("X", X)
                 Xs = X - X_mean
 
                 # Pass the zero-subtracted Xs in to the GP
@@ -328,7 +327,7 @@ class HSGP(Base):
 
         # If not provided, use Xs and c to set L
         if self._L is None:
-            assert isinstance(self._c, (numbers.Real, np.ndarray, pt.TensorVariable))
+            assert isinstance(self._c, numbers.Real | np.ndarray | pt.TensorVariable)
             self.L = pt.as_tensor(set_boundary(Xs, self._c))
         else:
             self.L = self._L
@@ -341,7 +340,7 @@ class HSGP(Base):
         i = int(self._drop_first is True)
         return phi[:, i:], pt.sqrt(psd[i:])
 
-    def prior(self, name: str, X: TensorLike, dims: Optional[str] = None):  # type: ignore
+    def prior(self, name: str, X: TensorLike, dims: str | None = None):  # type: ignore
         R"""
         Returns the (approximate) GP prior distribution evaluated over the input locations `X`.
         For usage examples, refer to `pm.gp.Latent`.
@@ -396,7 +395,7 @@ class HSGP(Base):
         elif self._parameterization == "centered":
             return self.mean_func(Xnew) + phi[:, i:] @ beta
 
-    def conditional(self, name: str, Xnew: TensorLike, dims: Optional[str] = None):  # type: ignore
+    def conditional(self, name: str, Xnew: TensorLike, dims: str | None = None):  # type: ignore
         R"""
         Returns the (approximate) conditional distribution evaluated over new input locations
         `Xnew`.
@@ -478,7 +477,7 @@ class HSGPPeriodic(Base):
     def __init__(
         self,
         m: int,
-        scale: Optional[Union[float, TensorLike]] = 1.0,
+        scale: float | TensorLike | None = 1.0,
         *,
         mean_func: Mean = Zero(),
         cov_func: Periodic,
@@ -589,7 +588,7 @@ class HSGPPeriodic(Base):
         psd = self.scale * self.cov_func.power_spectral_density_approx(J)
         return (phi_cos, phi_sin), psd
 
-    def prior(self, name: str, X: TensorLike, dims: Optional[str] = None):  # type: ignore
+    def prior(self, name: str, X: TensorLike, dims: str | None = None):  # type: ignore
         R"""
         Returns the (approximate) GP prior distribution evaluated over the input locations `X`.
         For usage examples, refer to `pm.gp.Latent`.
@@ -640,7 +639,7 @@ class HSGPPeriodic(Base):
         phi = phi_cos @ (psd * beta[:m]) + phi_sin[..., 1:] @ (psd[1:] * beta[m:])
         return self.mean_func(Xnew) + phi
 
-    def conditional(self, name: str, Xnew: TensorLike, dims: Optional[str] = None):  # type: ignore
+    def conditional(self, name: str, Xnew: TensorLike, dims: str | None = None):  # type: ignore
         R"""
         Returns the (approximate) conditional distribution evaluated over new input locations
         `Xnew`.
