@@ -29,6 +29,7 @@ from pytensor.compile.mode import Mode
 from pytensor.graph.basic import Variable
 from pytensor.graph.rewriting.basic import in2out
 from pytensor.tensor import TensorVariable
+from pytensor.tensor.random.op import RandomVariable
 from scipy import special as sp
 from scipy import stats as st
 
@@ -897,7 +898,18 @@ class BaseTestDistributionRandom:
         )
 
     def check_pymc_params_match_rv_op(self):
-        pytensor_dist_inputs = self.pymc_rv.get_parents()[0].inputs[3:]
+        op = self.pymc_rv.owner.op
+        if isinstance(op, RandomVariable):
+            _, _, _, *pytensor_dist_inputs = self.pymc_rv.owner.inputs
+        else:
+            inputs_signature, _ = op.signature.split("->")
+            pytensor_dist_inputs = [
+                inp
+                for inp, inp_signature in zip(
+                    self.pymc_rv.owner.inputs, inputs_signature.split(",")
+                )
+                if inp_signature not in ("[rng]", "[size]")
+            ]
         assert len(self.expected_rv_op_params) == len(pytensor_dist_inputs)
         for (expected_name, expected_value), actual_variable in zip(
             self.expected_rv_op_params.items(), pytensor_dist_inputs
@@ -917,18 +929,17 @@ class BaseTestDistributionRandom:
             expected_symbolic = tuple(pymc_rv.shape.eval())
             actual = pymc_rv.eval().shape
             assert actual == expected_symbolic
-            assert expected_symbolic == expected
+            assert expected_symbolic == expected, (size, expected_symbolic, expected)
 
         # test multi-parameters sampling for univariate distributions (with univariate inputs)
         if (
-            self.pymc_dist.rv_op.ndim_supp == 0
-            and self.pymc_dist.rv_op.ndims_params
-            and sum(self.pymc_dist.rv_op.ndims_params) == 0
+            self.pymc_dist.rv_type.ndim_supp == 0
+            and self.pymc_dist.rv_type.ndims_params
+            and sum(self.pymc_dist.rv_type.ndims_params) == 0
         ):
             params = {
                 k: p * np.ones(self.repeated_params_shape) for k, p in self.pymc_dist_params.items()
             }
-            self._instantiate_pymc_rv(params)
             sizes_to_check = [None, self.repeated_params_shape, (5, self.repeated_params_shape)]
             sizes_expected = [
                 (self.repeated_params_shape,),
